summary refs log tree commit diff
diff options
context:
space:
mode:
authorMatthew Hodgson <matthew@matrix.org>2018-07-19 10:59:02 +0100
committerMatthew Hodgson <matthew@matrix.org>2018-07-19 10:59:02 +0100
commitc0685f67c001ab156fb6922877c35f70536100dc (patch)
tree213d08f3459837f0b819f77dbaec92ba44f37fcc
parentchangelog (diff)
downloadsynapse-c0685f67c001ab156fb6922877c35f70536100dc.tar.xz
spell out that include_deleted_devices requires include_all_devices
-rw-r--r--synapse/storage/end_to_end_keys.py6
1 files changed, 5 insertions, 1 deletions
diff --git a/synapse/storage/end_to_end_keys.py b/synapse/storage/end_to_end_keys.py
index 6c28719420..ffe4d7235a 100644
--- a/synapse/storage/end_to_end_keys.py
+++ b/synapse/storage/end_to_end_keys.py
@@ -74,7 +74,8 @@ class EndToEndKeyStore(SQLBaseStore):
             include_all_devices (bool): whether to include entries for devices
                 that don't have device keys
             include_deleted_devices (bool): whether to include null entries for
                 devices which no longer exist (but were in the query_list)
         Returns:
             Dict mapping from user-id to dict mapping from device_id to
             dict containing "key_json", "device_display_name".
@@ -100,6 +101,9 @@ class EndToEndKeyStore(SQLBaseStore):
         query_clauses = []
         query_params = []
 
+        if include_all_devices is False:
+            include_deleted_devices = False
+
         if include_deleted_devices:
             deleted_devices = set(query_list)
@@ -74,7 +74,8 @@ class EndToEndKeyStore(SQLBaseStore):
                 that don't have device keys
             include_deleted_devices (bool): whether to include null entries for
-                devices which no longer exist (but were in the query_list)
+                devices which no longer exist (but were in the query_list).
+                This option only takes effect if include_all_devices is true.
         Returns:
             Dict mapping from user-id to dict mapping from device_id to